@@ -102,24 +102,21 @@
 #define	YYDEBUG	0		/* Default to no yydebug support */
 #endif
 
-int
-yyparse PARAMS ((void));
+int yyparse (void);
 
-static int
-yylex PARAMS ((void));
+static int yylex (void);
 
-void
-yyerror PARAMS ((char *));
+void yyerror (char *);
 
-static struct type * java_type_from_name PARAMS ((struct stoken));
-static void push_expression_name PARAMS ((struct stoken));
-static void push_fieldnames PARAMS ((struct stoken));
+static struct type *java_type_from_name (struct stoken);
+static void push_expression_name (struct stoken);
+static void push_fieldnames (struct stoken);
 
-static struct expression *copy_exp PARAMS ((struct expression *, int));
-static void insert_exp PARAMS ((int, struct expression *));
+static struct expression *copy_exp (struct expression *, int);
+static void insert_exp (int, struct expression *);
 
 
-#line 124 "jv-exp.y"
+#line 121 "jv-exp.y"
 typedef union
   {
     LONGEST lval;
@@ -141,11 +138,10 @@ typedef union
     struct internalvar *ivar;
     int *ivec;
   } YYSTYPE;
-#line 146 "jv-exp.y"
+#line 143 "jv-exp.y"
 
 /* YYSTYPE gets defined by %union */
-static int
-parse_number PARAMS ((char *, int, int, YYSTYPE *));
+static int parse_number (char *, int, int, YYSTYPE *);
 #include <stdio.h>
 
 #ifndef __cplusplus
@@ -256,19 +252,19 @@ static const short yyrhs[] = {    73,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   203,   204,   207,   215,   217,   220,   229,   235,   243,   248,
-   253,   263,   265,   269,   271,   274,   277,   279,   281,   283,
-   287,   290,   301,   306,   310,   313,   317,   319,   322,   324,
-   327,   329,   332,   356,   357,   361,   363,   366,   368,   371,
-   372,   373,   374,   375,   376,   383,   388,   393,   398,   401,
-   405,   408,   411,   414,   418,   420,   423,   427,   430,   434,
-   436,   440,   443,   448,   451,   453,   457,   475,   477,   481,
-   483,   485,   487,   488,   491,   496,   501,   503,   504,   505,
-   507,   509,   512,   517,   522,   524,   526,   528,   531,   536,
-   557,   564,   566,   568,   570,   574,   576,   578,   582,   584,
-   586,   591,   593,   595,   597,   599,   604,   606,   608,   612,
-   614,   618,   620,   623,   625,   629,   631,   635,   637,   641,
-   643,   647,   649,   652,   655,   661,   664,   666,   667,   671
+   199,   200,   203,   211,   213,   216,   225,   231,   239,   244,
+   249,   259,   261,   265,   267,   270,   273,   275,   277,   279,
+   283,   286,   297,   302,   306,   309,   313,   315,   318,   320,
+   323,   325,   328,   352,   353,   357,   359,   362,   364,   367,
+   368,   369,   370,   371,   372,   379,   384,   389,   394,   397,
+   401,   404,   407,   410,   414,   416,   419,   423,   426,   430,
+   432,   436,   439,   444,   447,   449,   453,   471,   473,   477,
+   479,   481,   483,   484,   487,   492,   497,   499,   500,   501,
+   503,   505,   508,   513,   518,   520,   522,   524,   527,   532,
+   553,   560,   562,   564,   566,   570,   572,   574,   578,   580,
+   582,   587,   589,   591,   593,   595,   600,   602,   604,   608,
+   610,   614,   616,   619,   621,   625,   627,   631,   633,   637,
+   639,   643,   645,   648,   651,   657,   660,   662,   663,   667
 };
 #endif
 
@@ -1031,7 +1027,7 @@ yyreduce:
   switch (yyn) {
 
 case 3:
-#line 208 "jv-exp.y"
+#line 204 "jv-exp.y"
 {
 		  write_exp_elt_opcode(OP_TYPE);
 		  write_exp_elt_type(yyvsp[0].tval);
@@ -1039,7 +1035,7 @@ case 3:
 		;
     break;}
 case 6:
-#line 222 "jv-exp.y"
+#line 218 "jv-exp.y"
 {
 		  write_exp_elt_opcode (OP_STRING);
 		  write_exp_string (yyvsp[0].sval);
@@ -1047,14 +1043,14 @@ case 6:
 		;
     break;}
 case 7:
-#line 231 "jv-exp.y"
+#line 227 "jv-exp.y"
 { write_exp_elt_opcode (OP_LONG);
 		  write_exp_elt_type (yyvsp[0].typed_val_int.type);
 		  write_exp_elt_longcst ((LONGEST)(yyvsp[0].typed_val_int.val));
 		  write_exp_elt_opcode (OP_LONG); ;
     break;}
 case 8:
-#line 236 "jv-exp.y"
+#line 232 "jv-exp.y"
 { YYSTYPE val;
 		  parse_number (yyvsp[0].sval.ptr, yyvsp[0].sval.length, 0, &val);
 		  write_exp_elt_opcode (OP_LONG);
@@ -1064,65 +1060,65 @@ case 8:
 		;
     break;}
 case 9:
-#line 244 "jv-exp.y"
+#line 240 "jv-exp.y"
 { write_exp_elt_opcode (OP_DOUBLE);
 		  write_exp_elt_type (yyvsp[0].typed_val_float.type);
 		  write_exp_elt_dblcst (yyvsp[0].typed_val_float.dval);
 		  write_exp_elt_opcode (OP_DOUBLE); ;
     break;}
 case 10:
-#line 249 "jv-exp.y"
+#line 245 "jv-exp.y"
 { write_exp_elt_opcode (OP_LONG);
 		  write_exp_elt_type (java_boolean_type);
 		  write_exp_elt_longcst ((LONGEST)yyvsp[0].lval);
 		  write_exp_elt_opcode (OP_LONG); ;
     break;}
 case 13:
-#line 266 "jv-exp.y"
+#line 262 "jv-exp.y"
 { yyval.tval = java_boolean_type; ;
     break;}
 case 16:
-#line 276 "jv-exp.y"
+#line 272 "jv-exp.y"
 { yyval.tval = java_byte_type; ;
     break;}
 case 17:
-#line 278 "jv-exp.y"
+#line 274 "jv-exp.y"
 { yyval.tval = java_short_type; ;
     break;}
 case 18:
-#line 280 "jv-exp.y"
+#line 276 "jv-exp.y"
 { yyval.tval = java_int_type; ;
     break;}
 case 19:
-#line 282 "jv-exp.y"
+#line 278 "jv-exp.y"
 { yyval.tval = java_long_type; ;
     break;}
 case 20:
-#line 284 "jv-exp.y"
+#line 280 "jv-exp.y"
 { yyval.tval = java_char_type; ;
     break;}
 case 21:
-#line 289 "jv-exp.y"
+#line 285 "jv-exp.y"
 { yyval.tval = java_float_type; ;
     break;}
 case 22:
-#line 291 "jv-exp.y"
+#line 287 "jv-exp.y"
 { yyval.tval = java_double_type; ;
     break;}
 case 23:
-#line 303 "jv-exp.y"
+#line 299 "jv-exp.y"
 { yyval.tval = java_type_from_name (yyvsp[0].sval); ;
     break;}
 case 25:
-#line 312 "jv-exp.y"
+#line 308 "jv-exp.y"
 { yyval.tval = java_array_type (yyvsp[-1].tval, yyvsp[0].lval); ;
     break;}
 case 26:
-#line 314 "jv-exp.y"
+#line 310 "jv-exp.y"
 { yyval.tval = java_array_type (java_type_from_name (yyvsp[-1].sval), yyvsp[0].lval); ;
     break;}
 case 33:
-#line 334 "jv-exp.y"
+#line 330 "jv-exp.y"
 { yyval.sval.length = yyvsp[-2].sval.length + yyvsp[0].sval.length + 1;
 		  if (yyvsp[-2].sval.ptr + yyvsp[-2].sval.length + 1 == yyvsp[0].sval.ptr
 		      && yyvsp[-2].sval.ptr[yyvsp[-2].sval.length] == '.')
@@ -1136,87 +1132,87 @@ case 33:
 		} ;
     break;}
 case 35:
-#line 358 "jv-exp.y"
+#line 354 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_COMMA); ;
     break;}
 case 39:
-#line 369 "jv-exp.y"
+#line 365 "jv-exp.y"
 { write_exp_elt_opcode (OP_THIS);
 		  write_exp_elt_opcode (OP_THIS); ;
     break;}
 case 45:
-#line 377 "jv-exp.y"
+#line 373 "jv-exp.y"
 { write_exp_elt_opcode (OP_ARRAY);
 		  write_exp_elt_longcst ((LONGEST) 0);
 		  write_exp_elt_longcst ((LONGEST) yyvsp[0].lval);
 		  write_exp_elt_opcode (OP_ARRAY); ;
     break;}
 case 46:
-#line 385 "jv-exp.y"
+#line 381 "jv-exp.y"
 { start_arglist (); ;
     break;}
 case 47:
-#line 390 "jv-exp.y"
+#line 386 "jv-exp.y"
 { yyval.lval = end_arglist () - 1; ;
     break;}
 case 48:
-#line 395 "jv-exp.y"
+#line 391 "jv-exp.y"
 { error ("FIXME - ClassInstanceCreationExpression"); ;
     break;}
 case 49:
-#line 400 "jv-exp.y"
+#line 396 "jv-exp.y"
 { arglist_len = 1; ;
     break;}
 case 50:
-#line 402 "jv-exp.y"
+#line 398 "jv-exp.y"
 { arglist_len++; ;
     break;}
 case 51:
-#line 407 "jv-exp.y"
+#line 403 "jv-exp.y"
 { arglist_len = 0; ;
     break;}
 case 53:
-#line 413 "jv-exp.y"
+#line 409 "jv-exp.y"
 { error ("FIXME - ArrayCreatiionExpression"); ;
     break;}
 case 54:
-#line 415 "jv-exp.y"
+#line 411 "jv-exp.y"
 { error ("FIXME - ArrayCreatiionExpression"); ;
     break;}
 case 58:
-#line 429 "jv-exp.y"
+#line 425 "jv-exp.y"
 { yyval.lval = 1; ;
     break;}
 case 59:
-#line 431 "jv-exp.y"
+#line 427 "jv-exp.y"
 { yyval.lval = yyvsp[-2].lval + 1; ;
     break;}
 case 61:
-#line 437 "jv-exp.y"
+#line 433 "jv-exp.y"
 { yyval.lval = 0; ;
     break;}
 case 62:
-#line 442 "jv-exp.y"
+#line 438 "jv-exp.y"
 { push_fieldnames (yyvsp[0].sval); ;
     break;}
 case 63:
-#line 444 "jv-exp.y"
+#line 440 "jv-exp.y"
 { push_fieldnames (yyvsp[0].sval); ;
     break;}
 case 64:
-#line 450 "jv-exp.y"
+#line 446 "jv-exp.y"
 { error ("method invocation not implemented"); ;
     break;}
 case 65:
-#line 452 "jv-exp.y"
+#line 448 "jv-exp.y"
 { error ("method invocation not implemented"); ;
     break;}
 case 66:
-#line 454 "jv-exp.y"
+#line 450 "jv-exp.y"
 { error ("method invocation not implemented"); ;
     break;}
 case 67:
-#line 459 "jv-exp.y"
+#line 455 "jv-exp.y"
 {
                   /* Emit code for the Name now, then exchange it in the
 		     expout array with the Expression's code.  We could
@@ -1235,57 +1231,57 @@ case 67:
 		;
     break;}
 case 68:
-#line 476 "jv-exp.y"
+#line 472 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_SUBSCRIPT); ;
     break;}
 case 69:
-#line 478 "jv-exp.y"
+#line 474 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_SUBSCRIPT); ;
     break;}
 case 71:
-#line 484 "jv-exp.y"
+#line 480 "jv-exp.y"
 { push_expression_name (yyvsp[0].sval); ;
     break;}
 case 75:
-#line 493 "jv-exp.y"
+#line 489 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_POSTINCREMENT); ;
     break;}
 case 76:
-#line 498 "jv-exp.y"
+#line 494 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_POSTDECREMENT); ;
     break;}
 case 80:
-#line 506 "jv-exp.y"
+#line 502 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_NEG); ;
     break;}
 case 81:
-#line 508 "jv-exp.y"
+#line 504 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_IND); ;
     break;}
 case 83:
-#line 514 "jv-exp.y"
+#line 510 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_PREINCREMENT); ;
     break;}
 case 84:
-#line 519 "jv-exp.y"
+#line 515 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_PREDECREMENT); ;
     break;}
 case 86:
-#line 525 "jv-exp.y"
+#line 521 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_COMPLEMENT); ;
     break;}
 case 87:
-#line 527 "jv-exp.y"
+#line 523 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_LOGICAL_NOT); ;
     break;}
 case 89:
-#line 533 "jv-exp.y"
+#line 529 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_CAST);
 		  write_exp_elt_type (java_array_type (yyvsp[-3].tval, yyvsp[-2].lval));
 		  write_exp_elt_opcode (UNOP_CAST); ;
     break;}
 case 90:
-#line 537 "jv-exp.y"
+#line 533 "jv-exp.y"
 {
 		  int exp_size = expout_ptr;
 		  int last_exp_size = length_of_subexp(expout, expout_ptr);
@@ -1308,99 +1304,99 @@ case 90:
 		;
     break;}
 case 91:
-#line 558 "jv-exp.y"
+#line 554 "jv-exp.y"
 { write_exp_elt_opcode (UNOP_CAST);
 		  write_exp_elt_type (java_array_type (java_type_from_name (yyvsp[-3].sval), yyvsp[-2].lval));
 		  write_exp_elt_opcode (UNOP_CAST); ;
     break;}
 case 93:
-#line 567 "jv-exp.y"
+#line 563 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_MUL); ;
     break;}
 case 94:
-#line 569 "jv-exp.y"
+#line 565 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_DIV); ;
     break;}
 case 95:
-#line 571 "jv-exp.y"
+#line 567 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_REM); ;
     break;}
 case 97:
-#line 577 "jv-exp.y"
+#line 573 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_ADD); ;
     break;}
 case 98:
-#line 579 "jv-exp.y"
+#line 575 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_SUB); ;
     break;}
 case 100:
-#line 585 "jv-exp.y"
+#line 581 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_LSH); ;
     break;}
 case 101:
-#line 587 "jv-exp.y"
+#line 583 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_RSH); ;
     break;}
 case 103:
-#line 594 "jv-exp.y"
+#line 590 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_LESS); ;
     break;}
 case 104:
-#line 596 "jv-exp.y"
+#line 592 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_GTR); ;
     break;}
 case 105:
-#line 598 "jv-exp.y"
+#line 594 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_LEQ); ;
     break;}
 case 106:
-#line 600 "jv-exp.y"
+#line 596 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_GEQ); ;
     break;}
 case 108:
-#line 607 "jv-exp.y"
+#line 603 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_EQUAL); ;
     break;}
 case 109:
-#line 609 "jv-exp.y"
+#line 605 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_NOTEQUAL); ;
     break;}
 case 111:
-#line 615 "jv-exp.y"
+#line 611 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_BITWISE_AND); ;
     break;}
 case 113:
-#line 621 "jv-exp.y"
+#line 617 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_BITWISE_XOR); ;
     break;}
 case 115:
-#line 626 "jv-exp.y"
+#line 622 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_BITWISE_IOR); ;
     break;}
 case 117:
-#line 632 "jv-exp.y"
+#line 628 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_LOGICAL_AND); ;
     break;}
 case 119:
-#line 638 "jv-exp.y"
+#line 634 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_LOGICAL_OR); ;
     break;}
 case 121:
-#line 644 "jv-exp.y"
+#line 640 "jv-exp.y"
 { write_exp_elt_opcode (TERNOP_COND); ;
     break;}
 case 124:
-#line 654 "jv-exp.y"
+#line 650 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_ASSIGN); ;
     break;}
 case 125:
-#line 656 "jv-exp.y"
+#line 652 "jv-exp.y"
 { write_exp_elt_opcode (BINOP_ASSIGN_MODIFY);
 		  write_exp_elt_opcode (yyvsp[-1].opcode);
 		  write_exp_elt_opcode (BINOP_ASSIGN_MODIFY); ;
     break;}
 case 126:
-#line 663 "jv-exp.y"
+#line 659 "jv-exp.y"
 { push_expression_name (yyvsp[0].sval); ;
     break;}
 }
@@ -1625,7 +1621,7 @@ yyerrhandle:
     }
   return 1;
 }
-#line 675 "jv-exp.y"
+#line 671 "jv-exp.y"
 
 /* Take care of parsing a number (anything that starts with a digit).
    Set yylval and return the token type; update lexptr.
