@@ -1,5 +1,5 @@
 /* Java language support definitions for GDB, the GNU debugger.
-   Copyright 1997-2000 Free Software Foundation, Inc.
+   Copyright 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -18,11 +18,9 @@
    Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-extern int
-java_parse PARAMS ((void));	/* Defined in jv-exp.y */
+extern int java_parse (void);	/* Defined in jv-exp.y */
 
-extern void
-java_error PARAMS ((char *));	/* Defined in jv-exp.y */
+extern void java_error (char *);	/* Defined in jv-exp.y */
 
 /* sizeof (struct Object) */
 #define JAVA_OBJECT_SIZE (get_java_object_header_size ())
@@ -44,25 +42,25 @@ extern int java_val_print (struct type *, char *, int, CORE_ADDR,
 extern int java_value_print (struct value *, struct ui_file *, int,
 			     enum val_prettyprint);
 
-extern value_ptr java_class_from_object PARAMS ((value_ptr));
+extern value_ptr java_class_from_object (value_ptr);
 
-extern struct type *type_from_class PARAMS ((struct value *));
+extern struct type *type_from_class (struct value *);
 
-extern struct type *java_primitive_type PARAMS ((int signature));
+extern struct type *java_primitive_type (int signature);
 
-extern struct type *java_primitive_type_from_name PARAMS ((char *, int));
+extern struct type *java_primitive_type_from_name (char *, int);
 
-extern struct type *java_array_type PARAMS ((struct type *, int));
+extern struct type *java_array_type (struct type *, int);
 
-extern struct type *get_java_object_type PARAMS ((void));
-extern int get_java_object_header_size PARAMS ((void));
+extern struct type *get_java_object_type (void);
+extern int get_java_object_header_size (void);
 
-extern struct type *java_lookup_class PARAMS ((char *));
+extern struct type *java_lookup_class (char *);
 
-extern int is_object_type PARAMS ((struct type *));
+extern int is_object_type (struct type *);
 
 /* Defined in jv-typeprint.c */
 extern void java_print_type (struct type *, char *, struct ui_file *, int,
 			     int);
 
-extern char *java_demangle_type_signature PARAMS ((char *));
+extern char *java_demangle_type_signature (char *);
