@@ -1,5 +1,6 @@
 /* Remote target glue for the ROM68K ROM monitor.
-   Copyright 1988, 1991, 1992, 1993, 1994, 1995 Free Software Foundation, Inc.
+   Copyright 1988, 1991, 1992, 1993, 1994, 1995, 1998, 1999, 2000, 2001
+   Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -23,15 +24,12 @@
 #include "target.h"
 #include "monitor.h"
 #include "serial.h"
+#include "regcache.h"
 
-static void rom68k_open PARAMS ((char *args, int from_tty));
+static void rom68k_open (char *args, int from_tty);
 
 static void
-rom68k_supply_register (regname, regnamelen, val, vallen)
-     char *regname;
-     int regnamelen;
-     char *val;
-     int vallen;
+rom68k_supply_register (char *regname, int regnamelen, char *val, int vallen)
 {
   int numregs;
   int regno;
@@ -149,15 +147,13 @@ init_rom68k_cmds (void)
 }				/* init_rom68k_cmds */
 
 static void
-rom68k_open (args, from_tty)
-     char *args;
-     int from_tty;
+rom68k_open (char *args, int from_tty)
 {
   monitor_open (args, &rom68k_cmds, from_tty);
 }
 
 void
-_initialize_rom68k ()
+_initialize_rom68k (void)
 {
   init_rom68k_cmds ();
   init_monitor_ops (&rom68k_ops);
